package sample.hw_android_sdk_v100;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.ColorMatrix;
import android.graphics.ColorMatrixColorFilter;
import android.graphics.Paint;

public class BitmapUtil {
	private static final int MAX_IMAGE_PIXEL_SIZE = 2048; 
	
	private BitmapUtil() { }

	/***
	 * Image를 흑백으로 변경하고, resize한다.
	 * @param bmpOriginal 비트맵
	 * @param width		 변경하고싶은 넓이
	 * @param height	변경하고 싶은 높이
	 * @return
	 */
	public static Bitmap toGrayscale(Bitmap bmpOriginal, int width, int height)
	{

		Bitmap bmpGrayscale = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
		Canvas c = new Canvas(bmpGrayscale);
		Paint paint = new Paint();
		ColorMatrix cm = new ColorMatrix();
		cm.setSaturation(0);
		ColorMatrixColorFilter f = new ColorMatrixColorFilter(cm);
		paint.setColorFilter(f);
		c.drawBitmap(bmpOriginal, 0, 0, paint);
		return bmpGrayscale;
	}

	/***
	 * Image를 1bit으로 변경
	 * @param bmpOriginal
	 * @return
	 */
	public static Bitmap toOneBit(Bitmap bmpOriginal)
	{
		int height = bmpOriginal.getHeight();
		int width = bmpOriginal.getWidth();
		int[] pixels = new int[width * height];
		bmpOriginal.getPixels(pixels, 0, width, 0, 0, width, height);

		for (int y = 0; y < height; y++) {
			// Iterate over width
			for (int x = 0; x < width; x++) {
				int pixel = bmpOriginal.getPixel(x, y);
				int lowestBit = pixel & 0xff;
				if(lowestBit<200)
					bmpOriginal.setPixel(x,y, Color.BLACK);
				else
					bmpOriginal.setPixel(x,y,Color.WHITE);
			}
		}
		return bmpOriginal;
	}
}
